<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Sophia After Dark
 * @since 1.0.0
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}

// Remove URL field from comments
function sophia_after_dark_remove_url_comments($fields) {
    unset($fields['url']);
    return $fields;
}
add_filter('comment_form_default_fields', 'sophia_after_dark_remove_url_comments');

// Edit Cookie consent text from comments
function sophia_after_dark_comment_form_change_cookies($fields) {
    $commenter = wp_get_current_commenter();
    $consent = empty($commenter['comment_author_email']) ? '' : ' checked="checked"';
    $fields['cookies'] = '<p class="comment-form-cookies-consent"><input id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" type="checkbox" value="yes"' . esc_attr($consent) . ' /><label for="wp-comment-cookies-consent">' . esc_html__('Save my Name & Email for the next time I comment.', 'sophia-after-dark') . '</label></p>';
    return $fields;
}
add_filter('comment_form_default_fields', 'sophia_after_dark_comment_form_change_cookies');

// Edit comment-notes text from comments
function sophia_after_dark_modify_text_before_comment_form($arg) {
    $arg['comment_notes_before'] = wp_kses_post(
        '<p class="comment-notes">' . 
        esc_html__('All comments are manually reviewed and moderated.', 'sophia-after-dark') . 
        '<br><span class="required-field-message">' . 
        esc_html__('Required fields are marked ', 'sophia-after-dark') . 
        '<span class="required">*</span></span></p>'
    );
    return $arg;
}
add_filter('comment_form_defaults', 'sophia_after_dark_modify_text_before_comment_form');

// Add note below comment form about privacy policy consent
function sophia_after_dark_modify_text_comment_form($post_id) {
    printf(
        '<span class="submit-comment-note">%s</span>', 
        wp_kses(
            __('By commenting, you consent to our <a href="/privacy-policy">Privacy Policy</a>', 'sophia-after-dark'), 
            array('a' => array('href' => array()))
        )
    );
}
add_action('comment_form', 'sophia_after_dark_modify_text_comment_form');

?>

<div id="comments" class="comments-area">
	<?php
	if ( have_comments() ) :
		?>
		<h2 class="comments-title">
			<?php
			$sophia_after_dark_comment_count = get_comments_number();
			if ( '1' === $sophia_after_dark_comment_count ) {
				printf(
					/* translators: 1: title. */
					esc_html__( 'One Comment on &ldquo;%1$s&rdquo;', 'sophia-after-dark' ),
					'<span>' . esc_html(get_the_title()) . '</span>'
				);
			} else {
				printf(
					/* translators: 1: comment count number, 2: title. */
					esc_html( _nx( '%1$s Comments on &ldquo;%2$s&rdquo;', '%1$s Comments on &ldquo;%2$s&rdquo;', $sophia_after_dark_comment_count, 'comments title', 'sophia-after-dark' ) ),
					number_format_i18n( $sophia_after_dark_comment_count ),
					'<span>' . esc_html(get_the_title()) . '</span>'
				);
			}
			?>
		</h2>

		<?php the_comments_navigation(); ?>

		<ol class="comment-list">
			<?php
			wp_list_comments( array(
				'style'      => 'ol',
				'short_ping' => true,
			) );
			?>
		</ol>

		<?php
		the_comments_navigation();

		if ( ! comments_open() ) :
			?>
			<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'sophia-after-dark' ); ?></p>
			<?php
		endif;

	endif;

	comment_form();
	?>

</div>
